@@ -1,26 +1,10 @@
 import ast
 import string
-import sys
 from collections import deque
-from typing import Any, Dict, List, Tuple, Union
+from typing import Any, Dict, List, Union
 
 from flynt.exceptions import ConversionRefused, FlyntException
-from flynt.utils import ast_formatted_value, ast_string_node
-
-
-def matching_call(node: ast.Call) -> bool:
-    """
-    Check if an ast Node represents a "...".format() call.
-    """
-    func = node.func
-    if not isinstance(func, ast.Attribute):
-        return False
-    call_from_string = hasattr(func, "value") and (
-        isinstance(func.value, ast.Str)
-        or (isinstance(func.value, ast.Constant) and isinstance(func.value.value, str))
-    )
-    return isinstance(node, ast.Call) and call_from_string and func.attr == "format"
-
+from flynt.utils.utils import ast_formatted_value, ast_string_node
 
 stdlib_parse = string.Formatter().parse
 
@@ -29,7 +13,7 @@ def joined_string(
     fmt_call: ast.Call,
     *,
     aggressive: bool = False,
-) -> Tuple[Union[ast.JoinedStr, ast.Str], bool]:
+) -> Union[ast.JoinedStr, ast.Str]:
     """Transform a "...".format() call node into a f-string node."""
     assert isinstance(fmt_call.func, ast.Attribute) and isinstance(
         fmt_call.func.value,
@@ -42,9 +26,7 @@ def joined_string(
         inserted_value_nodes += list(ast.walk(a))
     for kw in fmt_call.keywords:
         inserted_value_nodes += list(ast.walk(kw.value))
-    str_in_str = any(
-        isinstance(n, (ast.Str, ast.JoinedStr)) for n in inserted_value_nodes
-    )
+    any(isinstance(n, (ast.Str, ast.JoinedStr)) for n in inserted_value_nodes)
 
     for i, val in enumerate(fmt_call.args):
         var_map[i] = val
@@ -52,7 +34,7 @@ def joined_string(
     splits = deque(stdlib_parse(string))
 
     seq_ctr = 0
-    new_segments: List[ast.AST] = []
+    new_segments: List[Union[ast.Str, ast.FormattedValue]] = []
     manual_field_ordering = False
 
     for raw, var_name, fmt_str, conversion in splits:
@@ -103,31 +85,9 @@ def joined_string(
             f"Some variables were never used: {var_map} - skipping conversion, it's a risk of bug.",
         )
 
-    def is_literal_string(node):
-        if sys.version_info < (3, 8):
-            return isinstance(node, ast.Str)
-        return isinstance(node, ast.Constant) and isinstance(node.value, str)
-
-    def literal_string_value(node):
-        if sys.version_info < (3, 8):
-            return node.s
-        return node.value
-
-    def fix_literals(segment):
-        if (
-            isinstance(segment, ast.FormattedValue)
-            and segment.format_spec is None
-            and is_literal_string(segment.value)
-        ):
-            return segment.value
-        return segment
-
-    new_segments = [fix_literals(e) for e in new_segments]
-
-    if all(is_literal_string(segment) for segment in new_segments):
-        return (
-            ast.Str("".join(literal_string_value(segment) for segment in new_segments)),
-            False,
+    if all(isinstance(segment, ast.Str) for segment in new_segments):
+        return ast.Str(
+            "".join(segment.value for segment in new_segments)  # type:ignore[misc]
         )
 
-    return ast.JoinedStr(new_segments), str_in_str
+    return ast.JoinedStr(new_segments)
