@@ -11,7 +11,7 @@ FORMATS = "diouxXeEfFgGcrsa"
 FORMAT_GROUP = f"[hlL]?[{FORMATS}]"
 FORMAT_GROUP_MATCH = f"[hlL]?([{FORMATS}])"
 
-PREFIX_GROUP = "[0-9]*[.]?[0-9]*"
+PREFIX_GROUP = "[+-]?[0-9]*[.]?[0-9]*"
 
 ANY_DICT = re.compile(r"(?<!%)%\([^)]+?\)")
 DICT_PATTERN = re.compile(rf"(%\([^)]+\){PREFIX_GROUP}{FORMAT_GROUP})")
@@ -30,11 +30,26 @@ def is_percent_stringify(node: ast.BinOp) -> bool:
     return (
         isinstance(node.left, ast.Str)
         and isinstance(node.op, ast.Mod)
-        and isinstance(node.right, tuple([ast.Tuple, ast.Dict, *supported_operands]))
+        and isinstance(
+            node.right, tuple([ast.Tuple, ast.List, ast.Dict, *supported_operands])
+        )
+    )
+
+
+def _is_builtin_int_call(val: ast.AST) -> bool:
+    return _is_int_call(val) or _is_len_call(val)
+
+
+def _is_int_call(val: ast.AST) -> bool:
+    return (
+        isinstance(val, ast.Call)
+        and isinstance(val.func, ast.Name)
+        and val.func.id == "int"
     )
 
 
 def _is_len_call(val: ast.AST) -> bool:
+    # assume built-in len always returns int
     return (
         isinstance(val, ast.Call)
         and isinstance(val.func, ast.Name)
@@ -53,6 +68,32 @@ def formatted_value(
         fmt_prefix = fmt_prefix.replace(".", "0")
 
     if fmt_spec in conversion_methods:
+        if fmt_spec == "s" and fmt_prefix:
+            # Strings are right aligned in percent fmt by default, and indicate
+            # left alignment through a negative prefix.
+            #
+            # fstrings left align by default, and separate signs from alignment
+            #
+            # Python even accepts float values here, for both percent fmt
+            # and fstrings
+            #
+            # In order to not have to figure out what sort of number we are
+            # dealing with, just look at the leading - sign (if there is one)
+            # and remove it for the conversion
+            if fmt_prefix.startswith("-"):
+                # Left alignment
+                return ast_formatted_value(
+                    val,
+                    fmt_str=f"{fmt_prefix[1:]}",
+                    conversion=conversion_methods[fmt_spec],
+                )
+            if aggressive and not fmt_prefix.startswith("-"):
+                # Right alignment
+                return ast_formatted_value(
+                    val,
+                    fmt_str=f">{fmt_prefix}",
+                    conversion=conversion_methods[fmt_spec],
+                )
         if not aggressive and fmt_prefix:
             raise ConversionRefused(
                 "Default text alignment has changed between percent fmt and fstrings. "
@@ -65,8 +106,8 @@ def formatted_value(
         )
     fmt_spec = translate_conversion_types.get(fmt_spec, fmt_spec)
     if fmt_spec == "d":
-        # assume built-in len always returns int
-        if not _is_len_call(val):
+        # test if is a built-in that returns int
+        if not _is_builtin_int_call(val):
             if not aggressive:
                 raise ConversionRefused(
                     "Skipping %d formatting - fstrings behave differently from % formatting.",
@@ -183,6 +224,25 @@ def transform_tuple(node: ast.BinOp, *, aggressive: bool = False) -> ast.JoinedS
     return ast.JoinedStr(segments)
 
 
+def transform_list(node: ast.BinOp, *, aggressive: bool = False) -> ast.JoinedStr:
+    """Convert a `BinOp` `%` formatted str with a list on the right to an f-string.
+
+    Takes an ast.BinOp representing `"1. %s 2. %s" % [a, b]`
+    and converted it to a ast.JoinedStr representing `f"1. {a} 2. {b}"`
+    Borrow the core logic by converting the list into a ast.Tuple
+
+    Args:
+       node (ast.BinOp): The node to convert to a f-string
+
+    Returns ast.JoinedStr (f-string)
+    """
+    assert isinstance(node.right, ast.List)
+
+    # convert the list to a tuple to use that code
+    node.right = ast.Tuple(elts=node.right.elts)
+    return transform_tuple(node, aggressive=aggressive)
+
+
 def transform_generic(
     node: ast.BinOp,
     aggressive: bool = False,
@@ -233,6 +293,9 @@ def transform_binop(
     if isinstance(node.right, ast.Tuple):
         return transform_tuple(node, aggressive=aggressive)
 
+    if isinstance(node.right, ast.List):
+        return transform_list(node, aggressive=aggressive)
+
     if isinstance(node.right, ast.Dict):
         # todo adapt transform dict to Dict literal
         return transform_dict(node, aggressive=aggressive)
